@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-# pylint: disable=W0613, C0116
-# type: ignore[union-attr]
+# pylint: disable=C0116,W0613
 # This program is dedicated to the public domain under the CC0 license.
 
 """
@@ -16,6 +15,7 @@ bot.
 """
 
 import logging
+from typing import Tuple, Dict, Any
 
 from telegram import InlineKeyboardMarkup, InlineKeyboardButton, Update
 from telegram.ext import (
@@ -64,19 +64,20 @@ END = ConversationHandler.END
 
 
 # Helper
-def _name_switcher(level):
+def _name_switcher(level: str) -> Tuple[str, str]:
     if level == PARENTS:
         return 'Father', 'Mother'
     return 'Brother', 'Sister'
 
 
 # Top level conversation callbacks
-def start(update: Update, context: CallbackContext) -> None:
+def start(update: Update, context: CallbackContext) -> str:
     """Select an action: Adding parent/child or show data."""
     text = (
-        'You may add a familiy member, yourself show the gathered data or end the '
-        'conversation. To abort, simply type /stop.'
+        "You may choose to add a family member, yourself, show the gathered data, or end the "
+        "conversation. To abort, simply type /stop."
     )
+
     buttons = [
         [
             InlineKeyboardButton(text='Add family member', callback_data=str(ADDING_MEMBER)),
@@ -89,13 +90,13 @@ def start(update: Update, context: CallbackContext) -> None:
     ]
     keyboard = InlineKeyboardMarkup(buttons)
 
-    # If we're starting over we don't need do send a new message
+    # If we're starting over we don't need to send a new message
     if context.user_data.get(START_OVER):
         update.callback_query.answer()
         update.callback_query.edit_message_text(text=text, reply_markup=keyboard)
     else:
         update.message.reply_text(
-            'Hi, I\'m FamiliyBot and here to help you gather information' 'about your family.'
+            "Hi, I'm Family Bot and I'm here to help you gather information about your family."
         )
         update.message.reply_text(text=text, reply_markup=keyboard)
 
@@ -103,8 +104,8 @@ def start(update: Update, context: CallbackContext) -> None:
     return SELECTING_ACTION
 
 
-def adding_self(update: Update, context: CallbackContext) -> None:
-    """Add information about youself."""
+def adding_self(update: Update, context: CallbackContext) -> str:
+    """Add information about yourself."""
     context.user_data[CURRENT_LEVEL] = SELF
     text = 'Okay, please tell me about yourself.'
     button = InlineKeyboardButton(text='Add info', callback_data=str(MALE))
@@ -116,10 +117,10 @@ def adding_self(update: Update, context: CallbackContext) -> None:
     return DESCRIBING_SELF
 
 
-def show_data(update: Update, context: CallbackContext) -> None:
+def show_data(update: Update, context: CallbackContext) -> str:
     """Pretty print gathered data."""
 
-    def prettyprint(user_data, level):
+    def prettyprint(user_data: Dict[str, Any], level: str) -> str:
         people = user_data.get(level)
         if not people:
             return '\nNo information yet.'
@@ -137,9 +138,9 @@ def show_data(update: Update, context: CallbackContext) -> None:
         return text
 
     user_data = context.user_data
-    text = 'Yourself:' + prettyprint(user_data, SELF)
-    text += '\n\nParents:' + prettyprint(user_data, PARENTS)
-    text += '\n\nChildren:' + prettyprint(user_data, CHILDREN)
+    text = f"Yourself:{prettyprint(user_data, SELF)}"
+    text += f"\n\nParents:{prettyprint(user_data, PARENTS)}"
+    text += f"\n\nChildren:{prettyprint(user_data, CHILDREN)}"
 
     buttons = [[InlineKeyboardButton(text='Back', callback_data=str(END))]]
     keyboard = InlineKeyboardMarkup(buttons)
@@ -151,14 +152,14 @@ def show_data(update: Update, context: CallbackContext) -> None:
     return SHOWING
 
 
-def stop(update: Update, context: CallbackContext) -> None:
+def stop(update: Update, context: CallbackContext) -> int:
     """End Conversation by command."""
     update.message.reply_text('Okay, bye.')
 
     return END
 
 
-def end(update: Update, context: CallbackContext) -> None:
+def end(update: Update, context: CallbackContext) -> int:
     """End conversation from InlineKeyboardButton."""
     update.callback_query.answer()
 
@@ -169,7 +170,7 @@ def end(update: Update, context: CallbackContext) -> None:
 
 
 # Second level conversation callbacks
-def select_level(update: Update, context: CallbackContext) -> None:
+def select_level(update: Update, context: CallbackContext) -> str:
     """Choose to add a parent or a child."""
     text = 'You may add a parent or a child. Also you can show the gathered data or go back.'
     buttons = [
@@ -190,7 +191,7 @@ def select_level(update: Update, context: CallbackContext) -> None:
     return SELECTING_LEVEL
 
 
-def select_gender(update: Update, context: CallbackContext) -> None:
+def select_gender(update: Update, context: CallbackContext) -> str:
     """Choose to add mother or father."""
     level = update.callback_query.data
     context.user_data[CURRENT_LEVEL] = level
@@ -201,8 +202,8 @@ def select_gender(update: Update, context: CallbackContext) -> None:
 
     buttons = [
         [
-            InlineKeyboardButton(text='Add ' + male, callback_data=str(MALE)),
-            InlineKeyboardButton(text='Add ' + female, callback_data=str(FEMALE)),
+            InlineKeyboardButton(text=f'Add {male}', callback_data=str(MALE)),
+            InlineKeyboardButton(text=f'Add {female}', callback_data=str(FEMALE)),
         ],
         [
             InlineKeyboardButton(text='Show data', callback_data=str(SHOWING)),
@@ -217,7 +218,7 @@ def select_gender(update: Update, context: CallbackContext) -> None:
     return SELECTING_GENDER
 
 
-def end_second_level(update: Update, context: CallbackContext) -> None:
+def end_second_level(update: Update, context: CallbackContext) -> int:
     """Return to top level conversation."""
     context.user_data[START_OVER] = True
     start(update, context)
@@ -226,7 +227,7 @@ def end_second_level(update: Update, context: CallbackContext) -> None:
 
 
 # Third level callbacks
-def select_feature(update: Update, context: CallbackContext) -> None:
+def select_feature(update: Update, context: CallbackContext) -> str:
     """Select a feature to update for the person."""
     buttons = [
         [
@@ -253,7 +254,7 @@ def select_feature(update: Update, context: CallbackContext) -> None:
     return SELECTING_FEATURE
 
 
-def ask_for_input(update: Update, context: CallbackContext) -> None:
+def ask_for_input(update: Update, context: CallbackContext) -> str:
     """Prompt user to input data for selected feature."""
     context.user_data[CURRENT_FEATURE] = update.callback_query.data
     text = 'Okay, tell me.'
@@ -264,7 +265,7 @@ def ask_for_input(update: Update, context: CallbackContext) -> None:
     return TYPING
 
 
-def save_input(update: Update, context: CallbackContext) -> None:
+def save_input(update: Update, context: CallbackContext) -> str:
     """Save input for feature and return to feature selection."""
     user_data = context.user_data
     user_data[FEATURES][user_data[CURRENT_FEATURE]] = update.message.text
@@ -274,7 +275,7 @@ def save_input(update: Update, context: CallbackContext) -> None:
     return select_feature(update, context)
 
 
-def end_describing(update: Update, context: CallbackContext) -> None:
+def end_describing(update: Update, context: CallbackContext) -> int:
     """End gathering of features and return to parent conversation."""
     user_data = context.user_data
     level = user_data[CURRENT_LEVEL]
@@ -292,14 +293,15 @@ def end_describing(update: Update, context: CallbackContext) -> None:
     return END
 
 
-def stop_nested(update: Update, context: CallbackContext) -> None:
+def stop_nested(update: Update, context: CallbackContext) -> str:
     """Completely end conversation from within nested conversation."""
     update.message.reply_text('Okay, bye.')
 
     return STOPPING
 
 
-def main():
+def main() -> None:
+    """Run the bot."""
     # Create the Updater and pass it your bot's token.
     updater = Updater("TOKEN")
 
@@ -326,7 +328,7 @@ def main():
         map_to_parent={
             # Return to second level menu
             END: SELECTING_LEVEL,
-            # End conversation alltogether
+            # End conversation altogether
             STOPPING: STOPPING,
         },
     )
@@ -350,13 +352,13 @@ def main():
             SHOWING: SHOWING,
             # Return to top level menu
             END: SELECTING_ACTION,
-            # End conversation alltogether
+            # End conversation altogether
             STOPPING: END,
         },
     )
 
     # Set up top level ConversationHandler (selecting action)
-    # Because the states of the third level conversation map to the ones of the econd level
+    # Because the states of the third level conversation map to the ones of the second level
     # conversation, we need to make sure the top level conversation can also handle them
     selection_handlers = [
         add_member_conv,
