@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ import warnings
 from typing import TYPE_CHECKING, List, Optional, Tuple, Type, TypeVar
 
 from telegram.utils.types import JSONDict
+from telegram.utils.deprecate import set_new_attribute_deprecated
 
 if TYPE_CHECKING:
     from telegram import Bot
@@ -34,27 +35,43 @@ TO = TypeVar('TO', bound='TelegramObject', covariant=True)
 
 
 class TelegramObject:
-    """Base class for most telegram objects."""
+    """Base class for most Telegram objects."""
 
     _id_attrs: Tuple[object, ...] = ()
 
+    # Adding slots reduces memory usage & allows for faster attribute access.
+    # Only instance variables should be added to __slots__.
+    # We add __dict__ here for backward compatibility & also to avoid repetition for subclasses.
+    __slots__ = ('__dict__',)
+
     def __str__(self) -> str:
         return str(self.to_dict())
 
     def __getitem__(self, item: str) -> object:
-        return self.__dict__[item]
+        return getattr(self, item, None)
+
+    def __setattr__(self, key: str, value: object) -> None:
+        set_new_attribute_deprecated(self, key, value)
 
     @staticmethod
-    def parse_data(data: Optional[JSONDict]) -> Optional[JSONDict]:
-        if not data:
-            return None
-        return data.copy()
+    def _parse_data(data: Optional[JSONDict]) -> Optional[JSONDict]:
+        return None if data is None else data.copy()
 
     @classmethod
     def de_json(cls: Type[TO], data: Optional[JSONDict], bot: 'Bot') -> Optional[TO]:
-        data = cls.parse_data(data)
+        """Converts JSON data to a Telegram object.
 
-        if not data:
+        Args:
+            data (Dict[:obj:`str`, ...]): The JSON data.
+            bot (:class:`telegram.Bot`): The bot associated with this object.
+
+        Returns:
+            The Telegram object.
+
+        """
+        data = cls._parse_data(data)
+
+        if data is None:
             return None
 
         if cls == TelegramObject:
@@ -63,28 +80,47 @@ class TelegramObject:
 
     @classmethod
     def de_list(cls: Type[TO], data: Optional[List[JSONDict]], bot: 'Bot') -> List[Optional[TO]]:
+        """Converts JSON data to a list of Telegram objects.
+
+        Args:
+            data (Dict[:obj:`str`, ...]): The JSON data.
+            bot (:class:`telegram.Bot`): The bot associated with these objects.
+
+        Returns:
+            A list of Telegram objects.
+
+        """
         if not data:
             return []
 
         return [cls.de_json(d, bot) for d in data]
 
     def to_json(self) -> str:
-        """
+        """Gives a JSON representation of object.
+
         Returns:
             :obj:`str`
-
         """
-
         return json.dumps(self.to_dict())
 
     def to_dict(self) -> JSONDict:
-        data = dict()
+        """Gives representation of object as :obj:`dict`.
 
-        for key in iter(self.__dict__):
+        Returns:
+            :obj:`dict`
+        """
+        data = {}
+
+        # We want to get all attributes for the class, using self.__slots__ only includes the
+        # attributes used by that class itself, and not its superclass(es). Hence we get its MRO
+        # and then get their attributes. The `[:-2]` slice excludes the `object` class & the
+        # TelegramObject class itself.
+        attrs = {attr for cls in self.__class__.__mro__[:-2] for attr in cls.__slots__}
+        for key in attrs:
             if key == 'bot' or key.startswith('_'):
                 continue
 
-            value = self.__dict__[key]
+            value = getattr(self, key, None)
             if value is not None:
                 if hasattr(value, 'to_dict'):
                     data[key] = value.to_dict()
