@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -277,8 +277,6 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                 new_obj[cls._replace_bot(k, memo)] = cls._replace_bot(val, memo)
             memo[obj_id] = new_obj
             return new_obj
-        # if '__dict__' in obj.__slots__, we already cover this here, that's why the
-        # __dict__ case comes below
         try:
             if hasattr(obj, '__slots__'):
                 for attr_name in new_obj.__slots__:
@@ -289,8 +287,11 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                             cls._replace_bot(getattr(new_obj, attr_name), memo), memo
                         ),
                     )
-                memo[obj_id] = new_obj
-                return new_obj
+                if '__dict__' in obj.__slots__:
+                    # In this case, we have already covered the case that obj has __dict__
+                    # Note that obj may have a __dict__ even if it's not in __slots__!
+                    memo[obj_id] = new_obj
+                    return new_obj
             if hasattr(obj, '__dict__'):
                 for attr_name, attr in new_obj.__dict__.items():
                     setattr(new_obj, attr_name, cls._replace_bot(attr, memo))
@@ -302,9 +303,8 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                 f'See the docs of BasePersistence.replace_bot for more information.',
                 RuntimeWarning,
             )
-            memo[obj_id] = obj
-            return obj
 
+        memo[obj_id] = obj
         return obj
 
     def insert_bot(self, obj: object) -> object:
@@ -379,8 +379,6 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                 new_obj[self._insert_bot(k, memo)] = self._insert_bot(val, memo)
             memo[obj_id] = new_obj
             return new_obj
-        # if '__dict__' in obj.__slots__, we already cover this here, that's why the
-        # __dict__ case comes below
         try:
             if hasattr(obj, '__slots__'):
                 for attr_name in obj.__slots__:
@@ -391,8 +389,11 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                             self._insert_bot(getattr(new_obj, attr_name), memo), memo
                         ),
                     )
-                memo[obj_id] = new_obj
-                return new_obj
+                if '__dict__' in obj.__slots__:
+                    # In this case, we have already covered the case that obj has __dict__
+                    # Note that obj may have a __dict__ even if it's not in __slots__!
+                    memo[obj_id] = new_obj
+                    return new_obj
             if hasattr(obj, '__dict__'):
                 for attr_name, attr in new_obj.__dict__.items():
                     setattr(new_obj, attr_name, self._insert_bot(attr, memo))
@@ -404,9 +405,8 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
                 f'See the docs of BasePersistence.insert_bot for more information.',
                 RuntimeWarning,
             )
-            memo[obj_id] = obj
-            return obj
 
+        memo[obj_id] = obj
         return obj
 
     @abstractmethod
