@@ -139,7 +139,9 @@ class CallbackContext(Generic[UD, CD, BD]):
     @bot_data.setter
     def bot_data(self, value: object) -> NoReturn:
         raise AttributeError(
-            "You can not assign a new value to bot_data, see https://git.io/Jt6ic"
+            "You can not assign a new value to bot_data, "
+            "see https://github.com/python-telegram-bot/python-telegram-bot/wiki/Storing-bot%2C"
+            "-user-and-chat-related-data "
         )
 
     @property
@@ -160,7 +162,9 @@ class CallbackContext(Generic[UD, CD, BD]):
     @chat_data.setter
     def chat_data(self, value: object) -> NoReturn:
         raise AttributeError(
-            "You can not assign a new value to chat_data, see https://git.io/Jt6ic"
+            "You can not assign a new value to chat_data, "
+            "see https://github.com/python-telegram-bot/python-telegram-bot/wiki/Storing-bot%2C"
+            "-user-and-chat-related-data "
         )
 
     @property
@@ -175,7 +179,9 @@ class CallbackContext(Generic[UD, CD, BD]):
     @user_data.setter
     def user_data(self, value: object) -> NoReturn:
         raise AttributeError(
-            "You can not assign a new value to user_data, see https://git.io/Jt6ic"
+            "You can not assign a new value to user_data, "
+            "see https://github.com/python-telegram-bot/python-telegram-bot/wiki/Storing-bot%2C"
+            "-user-and-chat-related-data "
         )
 
     def refresh_data(self) -> None:
