@@ -79,7 +79,8 @@ class ConversationHandler(Handler[Update, CCT]):
 
         Finally, ``ConversationHandler``, does *not* handle (edited) channel posts.
 
-    .. _`FAQ`: https://git.io/JtcyU
+    .. _`FAQ`: https://github.com/python-telegram-bot/python-telegram-bot/wiki\
+        /Frequently-Asked-Questions#what-do-the-per_-settings-in-conversationhandler-do
 
     The first collection, a ``list`` named :attr:`entry_points`, is used to initiate the
     conversation, for example with a :class:`telegram.ext.CommandHandler` or
@@ -119,7 +120,7 @@ class ConversationHandler(Handler[Update, CCT]):
         :attr:`END` to end the *parent* conversation from within the nested one. For an example on
         nested :class:`ConversationHandler` s, see our `examples`_.
 
-    .. _`examples`: https://github.com/python-telegram-bot/python-telegram-bot/blob/master/examples
+    .. _`examples`: https://github.com/python-telegram-bot/python-telegram-bot/blob/v13.x/examples
 
     Args:
         entry_points (List[:class:`telegram.ext.Handler`]): A list of ``Handler`` objects that can
