@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -37,23 +37,42 @@ class ForceReply(ReplyMarkup):
         selective (:obj:`bool`, optional): Use this parameter if you want to force reply from
             specific users only. Targets:
 
-            1) Users that are @mentioned in the text of the Message object.
-            2) If the bot's message is a reply (has reply_to_message_id), sender of the
+            1) Users that are @mentioned in the :attr:`~telegram.Message.text` of the
+               :class:`telegram.Message` object.
+            2) If the bot's message is a reply (has ``reply_to_message_id``), sender of the
                original message.
 
+        input_field_placeholder (:obj:`str`, optional): The placeholder to be shown in the input
+            field when the reply is active; 1-64 characters.
+
+            .. versionadded:: 13.7
+
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         force_reply (:obj:`True`): Shows reply interface to the user, as if they manually selected
             the bots message and tapped 'Reply'.
         selective (:obj:`bool`): Optional. Force reply from specific users only.
+        input_field_placeholder (:obj:`str`): Optional. The placeholder shown in the input
+            field when the reply is active.
+
+            .. versionadded:: 13.7
 
     """
 
-    def __init__(self, force_reply: bool = True, selective: bool = False, **_kwargs: Any):
+    __slots__ = ('selective', 'force_reply', 'input_field_placeholder', '_id_attrs')
+
+    def __init__(
+        self,
+        force_reply: bool = True,
+        selective: bool = False,
+        input_field_placeholder: str = None,
+        **_kwargs: Any,
+    ):
         # Required
         self.force_reply = bool(force_reply)
         # Optionals
         self.selective = bool(selective)
+        self.input_field_placeholder = input_field_placeholder
 
         self._id_attrs = (self.selective,)
