@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -75,6 +75,17 @@ class InlineQueryResultCachedVideo(InlineQueryResult):
 
     """
 
+    __slots__ = (
+        'reply_markup',
+        'caption_entities',
+        'caption',
+        'title',
+        'description',
+        'parse_mode',
+        'input_message_content',
+        'video_file_id',
+    )
+
     def __init__(
         self,
         id: str,  # pylint: disable=W0622
