@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -85,6 +85,21 @@ class InlineQueryResultMpeg4Gif(InlineQueryResult):
 
     """
 
+    __slots__ = (
+        'reply_markup',
+        'thumb_mime_type',
+        'caption_entities',
+        'mpeg4_duration',
+        'mpeg4_width',
+        'title',
+        'caption',
+        'parse_mode',
+        'input_message_content',
+        'mpeg4_url',
+        'mpeg4_height',
+        'thumb_url',
+    )
+
     def __init__(
         self,
         id: str,  # pylint: disable=W0622
