@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -79,6 +79,22 @@ class InlineQueryResultVenue(InlineQueryResult):
 
     """
 
+    __slots__ = (
+        'longitude',
+        'reply_markup',
+        'google_place_type',
+        'thumb_width',
+        'thumb_height',
+        'title',
+        'address',
+        'foursquare_id',
+        'foursquare_type',
+        'google_place_id',
+        'input_message_content',
+        'latitude',
+        'thumb_url',
+    )
+
     def __init__(
         self,
         id: str,  # pylint: disable=W0622
