@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -92,6 +92,22 @@ class InlineQueryResultVideo(InlineQueryResult):
 
     """
 
+    __slots__ = (
+        'video_url',
+        'reply_markup',
+        'caption_entities',
+        'caption',
+        'title',
+        'description',
+        'video_duration',
+        'parse_mode',
+        'mime_type',
+        'input_message_content',
+        'video_height',
+        'video_width',
+        'thumb_url',
+    )
+
     def __init__(
         self,
         id: str,  # pylint: disable=W0622
