@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -60,6 +60,18 @@ class InputVenueMessageContent(InputMessageContent):
 
     """
 
+    __slots__ = (
+        'longitude',
+        'google_place_type',
+        'title',
+        'address',
+        'foursquare_id',
+        'foursquare_type',
+        'google_place_id',
+        'latitude',
+        '_id_attrs',
+    )
+
     def __init__(
         self,
         latitude: float,
