@@ -40,7 +40,10 @@ class MessageEntity(TelegramObject):
             bot_command, url, email, phone_number, bold (bold text), italic (italic text),
             strikethrough, spoiler (spoiler message), code (monowidth string), pre
             (monowidth block), text_link (for clickable text URLs), text_mention
-            (for users without usernames).
+            (for users without usernames), custom_emoji (for inline custom emoji stickers).
+
+            .. versionadded:: 13.14
+                added inline custom emoji
         offset (:obj:`int`): Offset in UTF-16 code units to the start of the entity.
         length (:obj:`int`): Length of the entity in UTF-16 code units.
         url (:obj:`str`, optional): For :attr:`TEXT_LINK` only, url that will be opened after
@@ -49,6 +52,11 @@ class MessageEntity(TelegramObject):
              user.
         language (:obj:`str`, optional): For :attr:`PRE` only, the programming language of
             the entity text.
+         custom_emoji_id (:obj:`str`, optional): For :attr:`CUSTOM_EMOJI` only, unique identifier
+            of the custom emoji. Use :meth:`telegram.Bot.get_custom_emoji_stickers` to get full
+            information about the sticker.
+
+            .. versionadded:: 13.14
 
     Attributes:
         type (:obj:`str`): Type of the entity.
@@ -57,10 +65,22 @@ class MessageEntity(TelegramObject):
         url (:obj:`str`): Optional. Url that will be opened after user taps on the text.
         user (:class:`telegram.User`): Optional. The mentioned user.
         language (:obj:`str`): Optional. Programming language of the entity text.
+        custom_emoji_id (:obj:`str`): Optional. Unique identifier of the custom emoji.
+
+            .. versionadded:: 13.14
 
     """
 
-    __slots__ = ('length', 'url', 'user', 'type', 'language', 'offset', '_id_attrs')
+    __slots__ = (
+        'length',
+        'url',
+        'user',
+        'type',
+        'language',
+        'offset',
+        'custom_emoji_id',
+        '_id_attrs',
+    )
 
     def __init__(
         self,
@@ -70,6 +90,7 @@ class MessageEntity(TelegramObject):
         url: str = None,
         user: User = None,
         language: str = None,
+        custom_emoji_id: str = None,
         **_kwargs: Any,
     ):
         # Required
@@ -80,6 +101,7 @@ class MessageEntity(TelegramObject):
         self.url = url
         self.user = user
         self.language = language
+        self.custom_emoji_id = custom_emoji_id
 
         self._id_attrs = (self.type, self.offset, self.length)
 
@@ -130,6 +152,11 @@ class MessageEntity(TelegramObject):
 
     .. versionadded:: 13.10
     """
+    CUSTOM_EMOJI: ClassVar[str] = constants.MESSAGEENTITY_CUSTOM_EMOJI
+    """:const:`telegram.constants.MESSAGEENTITY_CUSTOM_EMOJI`
+
+    .. versionadded:: 13.14
+    """
     ALL_TYPES: ClassVar[List[str]] = constants.MESSAGEENTITY_ALL_TYPES
     """:const:`telegram.constants.MESSAGEENTITY_ALL_TYPES`\n
     List of all the types"""
