@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -53,6 +53,15 @@ class Invoice(TelegramObject):
 
     """
 
+    __slots__ = (
+        'currency',
+        'start_parameter',
+        'title',
+        'description',
+        'total_amount',
+        '_id_attrs',
+    )
+
     def __init__(
         self,
         title: str,
