@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -49,6 +49,16 @@ class ShippingAddress(TelegramObject):
 
     """
 
+    __slots__ = (
+        'post_code',
+        'city',
+        '_id_attrs',
+        'country_code',
+        'street_line2',
+        'street_line1',
+        'state',
+    )
+
     def __init__(
         self,
         country_code: str,
