@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -29,6 +29,9 @@ from telegram import (
     PreCheckoutQuery,
     ShippingQuery,
     TelegramObject,
+    ChatMemberUpdated,
+    constants,
+    ChatJoinRequest,
 )
 from telegram.poll import PollAnswer
 from telegram.utils.types import JSONDict
@@ -74,6 +77,25 @@ class Update(TelegramObject):
         poll_answer (:class:`telegram.PollAnswer`, optional): A user changed their answer
             in a non-anonymous poll. Bots receive new votes only in polls that were sent
             by the bot itself.
+        my_chat_member (:class:`telegram.ChatMemberUpdated`, optional): The bot's chat member
+            status was updated in a chat. For private chats, this update is received only when the
+            bot is blocked or unblocked by the user.
+
+            .. versionadded:: 13.4
+        chat_member (:class:`telegram.ChatMemberUpdated`, optional): A chat member's status was
+            updated in a chat. The bot must be an administrator in the chat and must explicitly
+            specify ``'chat_member'`` in the list of ``'allowed_updates'`` to receive these
+            updates (see :meth:`telegram.Bot.get_updates`, :meth:`telegram.Bot.set_webhook`,
+            :meth:`telegram.ext.Updater.start_polling` and
+            :meth:`telegram.ext.Updater.start_webhook`).
+
+            .. versionadded:: 13.4
+        chat_join_request (:class:`telegram.ChatJoinRequest`, optional): A request to join the
+            chat has been sent. The bot must have the
+            :attr:`telegram.ChatPermissions.can_invite_users` administrator right in the chat to
+            receive these updates.
+
+            .. versionadded:: 13.8
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
@@ -94,9 +116,110 @@ class Update(TelegramObject):
         poll_answer (:class:`telegram.PollAnswer`): Optional. A user changed their answer
             in a non-anonymous poll. Bots receive new votes only in polls that were sent
             by the bot itself.
+        my_chat_member (:class:`telegram.ChatMemberUpdated`): Optional. The bot's chat member
+            status was updated in a chat. For private chats, this update is received only when the
+            bot is blocked or unblocked by the user.
+
+            .. versionadded:: 13.4
+        chat_member (:class:`telegram.ChatMemberUpdated`): Optional. A chat member's status was
+            updated in a chat. The bot must be an administrator in the chat and must explicitly
+            specify ``'chat_member'`` in the list of ``'allowed_updates'`` to receive these
+            updates (see :meth:`telegram.Bot.get_updates`, :meth:`telegram.Bot.set_webhook`,
+            :meth:`telegram.ext.Updater.start_polling` and
+            :meth:`telegram.ext.Updater.start_webhook`).
+
+            .. versionadded:: 13.4
+        chat_join_request (:class:`telegram.ChatJoinRequest`): Optional. A request to join the
+            chat has been sent. The bot must have the ``'can_invite_users'`` administrator
+            right in the chat to receive these updates.
+
+            .. versionadded:: 13.8
 
     """
 
+    __slots__ = (
+        'callback_query',
+        'chosen_inline_result',
+        'pre_checkout_query',
+        'inline_query',
+        'update_id',
+        'message',
+        'shipping_query',
+        'poll',
+        'poll_answer',
+        'channel_post',
+        'edited_channel_post',
+        'edited_message',
+        '_effective_user',
+        '_effective_chat',
+        '_effective_message',
+        'my_chat_member',
+        'chat_member',
+        'chat_join_request',
+        '_id_attrs',
+    )
+
+    MESSAGE = constants.UPDATE_MESSAGE
+    """:const:`telegram.constants.UPDATE_MESSAGE`
+
+    .. versionadded:: 13.5"""
+    EDITED_MESSAGE = constants.UPDATE_EDITED_MESSAGE
+    """:const:`telegram.constants.UPDATE_EDITED_MESSAGE`
+
+    .. versionadded:: 13.5"""
+    CHANNEL_POST = constants.UPDATE_CHANNEL_POST
+    """:const:`telegram.constants.UPDATE_CHANNEL_POST`
+
+    .. versionadded:: 13.5"""
+    EDITED_CHANNEL_POST = constants.UPDATE_EDITED_CHANNEL_POST
+    """:const:`telegram.constants.UPDATE_EDITED_CHANNEL_POST`
+
+    .. versionadded:: 13.5"""
+    INLINE_QUERY = constants.UPDATE_INLINE_QUERY
+    """:const:`telegram.constants.UPDATE_INLINE_QUERY`
+
+    .. versionadded:: 13.5"""
+    CHOSEN_INLINE_RESULT = constants.UPDATE_CHOSEN_INLINE_RESULT
+    """:const:`telegram.constants.UPDATE_CHOSEN_INLINE_RESULT`
+
+    .. versionadded:: 13.5"""
+    CALLBACK_QUERY = constants.UPDATE_CALLBACK_QUERY
+    """:const:`telegram.constants.UPDATE_CALLBACK_QUERY`
+
+    .. versionadded:: 13.5"""
+    SHIPPING_QUERY = constants.UPDATE_SHIPPING_QUERY
+    """:const:`telegram.constants.UPDATE_SHIPPING_QUERY`
+
+    .. versionadded:: 13.5"""
+    PRE_CHECKOUT_QUERY = constants.UPDATE_PRE_CHECKOUT_QUERY
+    """:const:`telegram.constants.UPDATE_PRE_CHECKOUT_QUERY`
+
+    .. versionadded:: 13.5"""
+    POLL = constants.UPDATE_POLL
+    """:const:`telegram.constants.UPDATE_POLL`
+
+    .. versionadded:: 13.5"""
+    POLL_ANSWER = constants.UPDATE_POLL_ANSWER
+    """:const:`telegram.constants.UPDATE_POLL_ANSWER`
+
+    .. versionadded:: 13.5"""
+    MY_CHAT_MEMBER = constants.UPDATE_MY_CHAT_MEMBER
+    """:const:`telegram.constants.UPDATE_MY_CHAT_MEMBER`
+
+    .. versionadded:: 13.5"""
+    CHAT_MEMBER = constants.UPDATE_CHAT_MEMBER
+    """:const:`telegram.constants.UPDATE_CHAT_MEMBER`
+
+    .. versionadded:: 13.5"""
+    CHAT_JOIN_REQUEST = constants.UPDATE_CHAT_JOIN_REQUEST
+    """:const:`telegram.constants.UPDATE_CHAT_JOIN_REQUEST`
+
+    .. versionadded:: 13.8"""
+    ALL_TYPES = constants.UPDATE_ALL_TYPES
+    """:const:`telegram.constants.UPDATE_ALL_TYPES`
+
+    .. versionadded:: 13.5"""
+
     def __init__(
         self,
         update_id: int,
@@ -111,6 +234,9 @@ class Update(TelegramObject):
         pre_checkout_query: PreCheckoutQuery = None,
         poll: Poll = None,
         poll_answer: PollAnswer = None,
+        my_chat_member: ChatMemberUpdated = None,
+        chat_member: ChatMemberUpdated = None,
+        chat_join_request: ChatJoinRequest = None,
         **_kwargs: Any,
     ):
         # Required
@@ -127,6 +253,9 @@ class Update(TelegramObject):
         self.edited_channel_post = edited_channel_post
         self.poll = poll
         self.poll_answer = poll_answer
+        self.my_chat_member = my_chat_member
+        self.chat_member = chat_member
+        self.chat_join_request = chat_join_request
 
         self._effective_user: Optional['User'] = None
         self._effective_chat: Optional['Chat'] = None
@@ -170,6 +299,15 @@ class Update(TelegramObject):
         elif self.poll_answer:
             user = self.poll_answer.user
 
+        elif self.my_chat_member:
+            user = self.my_chat_member.from_user
+
+        elif self.chat_member:
+            user = self.chat_member.from_user
+
+        elif self.chat_join_request:
+            user = self.chat_join_request.from_user
+
         self._effective_user = user
         return user
 
@@ -203,6 +341,15 @@ class Update(TelegramObject):
         elif self.edited_channel_post:
             chat = self.edited_channel_post.chat
 
+        elif self.my_chat_member:
+            chat = self.my_chat_member.chat
+
+        elif self.chat_member:
+            chat = self.chat_member.chat
+
+        elif self.chat_join_request:
+            chat = self.chat_join_request.chat
+
         self._effective_chat = chat
         return chat
 
@@ -212,8 +359,10 @@ class Update(TelegramObject):
         :class:`telegram.Message`: The message included in this update, no matter what kind of
             update this is. Will be :obj:`None` for :attr:`inline_query`,
             :attr:`chosen_inline_result`, :attr:`callback_query` from inline messages,
-            :attr:`shipping_query`, :attr:`pre_checkout_query`, :attr:`poll` and
-            :attr:`poll_answer`.
+            :attr:`shipping_query`, :attr:`pre_checkout_query`, :attr:`poll`,
+            :attr:`poll_answer`, :attr:`my_chat_member`, :attr:`chat_member` as well as
+            :attr:`chat_join_request` in case the bot is missing the
+            :attr:`telegram.ChatPermissions.can_invite_users` administrator right in the chat.
 
         """
         if self._effective_message:
@@ -241,7 +390,8 @@ class Update(TelegramObject):
 
     @classmethod
     def de_json(cls, data: Optional[JSONDict], bot: 'Bot') -> Optional['Update']:
-        data = cls.parse_data(data)
+        """See :meth:`telegram.TelegramObject.de_json`."""
+        data = cls._parse_data(data)
 
         if not data:
             return None
@@ -259,5 +409,8 @@ class Update(TelegramObject):
         data['edited_channel_post'] = Message.de_json(data.get('edited_channel_post'), bot)
         data['poll'] = Poll.de_json(data.get('poll'), bot)
         data['poll_answer'] = PollAnswer.de_json(data.get('poll_answer'), bot)
+        data['my_chat_member'] = ChatMemberUpdated.de_json(data.get('my_chat_member'), bot)
+        data['chat_member'] = ChatMemberUpdated.de_json(data.get('chat_member'), bot)
+        data['chat_join_request'] = ChatJoinRequest.de_json(data.get('chat_join_request'), bot)
 
         return cls(**data)
