@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -30,7 +30,7 @@ except ImportError:
 
 from typing import Any, Union
 
-import certifi  # pylint: disable=E0401
+import certifi
 
 try:
     import telegram.vendor.ptb_urllib3.urllib3 as urllib3
@@ -58,7 +58,7 @@ except ImportError:  # pragma: no cover
         raise
 
 # pylint: disable=C0412
-from telegram import InputFile, InputMedia, TelegramError
+from telegram import InputFile, TelegramError
 from telegram.error import (
     BadRequest,
     ChatMigrated,
@@ -70,10 +70,11 @@ from telegram.error import (
     Unauthorized,
 )
 from telegram.utils.types import JSONDict
+from telegram.utils.deprecate import set_new_attribute_deprecated
 
 
 def _render_part(self: RequestField, name: str, value: str) -> str:  # pylint: disable=W0613
-    """
+    r"""
     Monkey patch urllib3.urllib3.fields.RequestField to make it *not* support RFC2231 compliant
     Content-Disposition headers since telegram servers don't understand it. Instead just escape
     \\ and " and replace any \n and \r with a space.
@@ -85,7 +86,7 @@ def _render_part(self: RequestField, name: str, value: str) -> str:  # pylint: d
 
 RequestField._render_part = _render_part  # type: ignore  # pylint: disable=W0212
 
-logging.getLogger('urllib3').setLevel(logging.WARNING)
+logging.getLogger('telegram.vendor.ptb_urllib3.urllib3').setLevel(logging.WARNING)
 
 USER_AGENT = 'Python Telegram Bot (https://github.com/python-telegram-bot/python-telegram-bot)'
 
@@ -93,23 +94,26 @@ USER_AGENT = 'Python Telegram Bot (https://github.com/python-telegram-bot/python
 class Request:
     """
     Helper class for python-telegram-bot which provides methods to perform POST & GET towards
-    telegram servers.
+    Telegram servers.
 
     Args:
-        con_pool_size (int): Number of connections to keep in the connection pool.
-        proxy_url (str): The URL to the proxy server. For example: `http://127.0.0.1:3128`.
-        urllib3_proxy_kwargs (dict): Arbitrary arguments passed as-is to `urllib3.ProxyManager`.
-            This value will be ignored if proxy_url is not set.
-        connect_timeout (int|float): The maximum amount of time (in seconds) to wait for a
-            connection attempt to a server to succeed. None will set an infinite timeout for
-            connection attempts. (default: 5.)
-        read_timeout (int|float): The maximum amount of time (in seconds) to wait between
-            consecutive read operations for a response from the server. None will set an infinite
-            timeout. This value is usually overridden by the various ``telegram.Bot`` methods.
-            (default: 5.)
+        con_pool_size (:obj:`int`): Number of connections to keep in the connection pool.
+        proxy_url (:obj:`str`): The URL to the proxy server. For example: `http://127.0.0.1:3128`.
+        urllib3_proxy_kwargs (:obj:`dict`): Arbitrary arguments passed as-is to
+            :obj:`urllib3.ProxyManager`. This value will be ignored if :attr:`proxy_url` is not
+            set.
+        connect_timeout (:obj:`int` | :obj:`float`): The maximum amount of time (in seconds) to
+            wait for a connection attempt to a server to succeed. :obj:`None` will set an
+            infinite timeout for connection attempts. Defaults to ``5.0``.
+        read_timeout (:obj:`int` | :obj:`float`): The maximum amount of time (in seconds) to wait
+            between consecutive read operations for a response from the server. :obj:`None` will
+            set an infinite timeout. This value is usually overridden by the various
+            :class:`telegram.Bot` methods. Defaults to ``5.0``.
 
     """
 
+    __slots__ = ('_connect_timeout', '_con_pool_size', '_con_pool', '__dict__')
+
     def __init__(
         self,
         con_pool_size: int = 1,
@@ -119,7 +123,7 @@ class Request:
         read_timeout: float = 5.0,
     ):
         if urllib3_proxy_kwargs is None:
-            urllib3_proxy_kwargs = dict()
+            urllib3_proxy_kwargs = {}
 
         self._connect_timeout = connect_timeout
 
@@ -188,12 +192,16 @@ class Request:
 
                 self._con_pool = mgr
 
+    def __setattr__(self, key: str, value: object) -> None:
+        set_new_attribute_deprecated(self, key, value)
+
     @property
     def con_pool_size(self) -> int:
         """The size of the connection pool used."""
         return self._con_pool_size
 
     def stop(self) -> None:
+        """Performs cleanup on shutdown."""
         self._con_pool.clear()  # type: ignore
 
     @staticmethod
@@ -204,7 +212,6 @@ class Request:
             dict: A JSON parsed as Python dict with results - on error this dict will be empty.
 
         """
-
         decoded_s = json_data.decode('utf-8', 'replace')
         try:
             data = json.loads(decoded_s)
@@ -231,7 +238,7 @@ class Request:
 
         Args:
             args: unnamed arguments, passed to urllib3 request.
-            kwargs: keyword arguments, passed tp urllib3 request.
+            kwargs: keyword arguments, passed to urllib3 request.
 
         Returns:
             bytes: A non-parsed JSON text.
@@ -288,7 +295,7 @@ class Request:
 
         Args:
             url (:obj:`str`): The web location we want to retrieve.
-            data (dict[str, str|int], optional): A dict of key/value pairs.
+            data (Dict[:obj:`str`, :obj:`str` | :obj:`int`], optional): A dict of key/value pairs.
             timeout (:obj:`int` | :obj:`float`, optional): If this value is specified, use it as
                 the read timeout from the server (instead of the one specified during creation of
                 the connection pool).
@@ -318,13 +325,9 @@ class Request:
                 # Urllib3 doesn't like floats it seems
                 data[key] = str(val)
             elif key == 'media':
-                # One media or multiple
-                if isinstance(val, InputMedia):
-                    # Attach and set val to attached name
-                    data[key] = val.to_json()
-                    if isinstance(val.media, InputFile):  # type: ignore
-                        data[val.media.attach] = val.media.field_tuple  # type: ignore
-                else:
+                files = True
+                # List of media
+                if isinstance(val, list):
                     # Attach and set val to attached name for all
                     media = []
                     for med in val:
@@ -336,7 +339,16 @@ class Request:
                             if "thumb" in media_dict:
                                 data[med.thumb.attach] = med.thumb.field_tuple
                     data[key] = json.dumps(media)
-                files = True
+                # Single media
+                else:
+                    # Attach and set val to attached name
+                    media_dict = val.to_dict()
+                    if isinstance(val.media, InputFile):
+                        data[val.media.attach] = val.media.field_tuple
+                        # if the file has a thumb, we also need to attach it to the data
+                        if "thumb" in media_dict:
+                            data[val.thumb.attach] = val.thumb.field_tuple
+                    data[key] = json.dumps(media_dict)
             elif isinstance(val, list):
                 # In case we're sending files, we need to json-dump lists manually
                 # As we can't know if that's the case, we just json-dump here
@@ -376,10 +388,10 @@ class Request:
         """Download a file by its URL.
 
         Args:
-            url (str): The web location we want to retrieve.
-            timeout (:obj:`int` | :obj:`float`): If this value is specified, use it as the read
-                timeout from the server (instead of the one specified during creation of the
-                connection pool).
+            url (:obj:`str`): The web location we want to retrieve.
+            timeout (:obj:`int` | :obj:`float`, optional): If this value is specified, use it as
+                the read timeout from the server (instead of the one specified during creation of
+                the connection pool).
             filename (:obj:`str`): The filename within the path to download the file.
 
         """
