@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,13 +16,37 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
+
 import pytest
 
-from telegram import Update, Message, Chat, User, TelegramError
+from telegram import (
+    Update,
+    Message,
+    Chat,
+    User,
+    TelegramError,
+    Bot,
+    InlineKeyboardMarkup,
+    InlineKeyboardButton,
+    CallbackQuery,
+)
 from telegram.ext import CallbackContext
 
+"""
+CallbackContext.refresh_data is tested in TestBasePersistence
+"""
+
 
 class TestCallbackContext:
+    def test_slot_behaviour(self, cdp, recwarn, mro_slots):
+        c = CallbackContext(cdp)
+        for attr in c.__slots__:
+            assert getattr(c, attr, 'err') != 'err', f"got extra slot '{attr}'"
+        assert not c.__dict__, f"got missing slot(s): {c.__dict__}"
+        assert len(mro_slots(c)) == len(set(mro_slots(c))), "duplicate slot"
+        c.args = c.args
+        assert len(recwarn) == 0, recwarn.list
+
     def test_non_context_dp(self, dp):
         with pytest.raises(ValueError):
             CallbackContext(dp)
@@ -152,3 +176,57 @@ class TestCallbackContext:
     def test_dispatcher_attribute(self, cdp):
         callback_context = CallbackContext(cdp)
         assert callback_context.dispatcher == cdp
+
+    def test_drop_callback_data_exception(self, bot, cdp):
+        non_ext_bot = Bot(bot.token)
+        update = Update(
+            0, message=Message(0, None, Chat(1, 'chat'), from_user=User(1, 'user', False))
+        )
+
+        callback_context = CallbackContext.from_update(update, cdp)
+
+        with pytest.raises(RuntimeError, match='This telegram.ext.ExtBot instance does not'):
+            callback_context.drop_callback_data(None)
+
+        try:
+            cdp.bot = non_ext_bot
+            with pytest.raises(RuntimeError, match='telegram.Bot does not allow for'):
+                callback_context.drop_callback_data(None)
+        finally:
+            cdp.bot = bot
+
+    def test_drop_callback_data(self, cdp, monkeypatch, chat_id):
+        monkeypatch.setattr(cdp.bot, 'arbitrary_callback_data', True)
+
+        update = Update(
+            0, message=Message(0, None, Chat(1, 'chat'), from_user=User(1, 'user', False))
+        )
+
+        callback_context = CallbackContext.from_update(update, cdp)
+        cdp.bot.send_message(
+            chat_id=chat_id,
+            text='test',
+            reply_markup=InlineKeyboardMarkup.from_button(
+                InlineKeyboardButton('test', callback_data='callback_data')
+            ),
+        )
+        keyboard_uuid = cdp.bot.callback_data_cache.persistence_data[0][0][0]
+        button_uuid = list(cdp.bot.callback_data_cache.persistence_data[0][0][2])[0]
+        callback_data = keyboard_uuid + button_uuid
+        callback_query = CallbackQuery(
+            id='1',
+            from_user=None,
+            chat_instance=None,
+            data=callback_data,
+        )
+        cdp.bot.callback_data_cache.process_callback_query(callback_query)
+
+        try:
+            assert len(cdp.bot.callback_data_cache.persistence_data[0]) == 1
+            assert list(cdp.bot.callback_data_cache.persistence_data[1]) == ['1']
+
+            callback_context.drop_callback_data(callback_query)
+            assert cdp.bot.callback_data_cache.persistence_data == ([], {})
+        finally:
+            cdp.bot.callback_data_cache.clear_callback_data()
+            cdp.bot.callback_data_cache.clear_callback_queries()
