@@ -45,6 +45,10 @@ def chat(bot):
         has_protected_content=True,
         join_to_send_messages=True,
         join_by_request=True,
+        has_restricted_voice_and_video_messages=True,
+        is_forum=True,
+        active_usernames=TestChat.active_usernames,
+        emoji_status_custom_emoji_id=TestChat.emoji_status_custom_emoji_id,
     )
 
 
@@ -70,6 +74,10 @@ class TestChat:
     has_private_forwards = True
     join_to_send_messages = True
     join_by_request = True
+    has_restricted_voice_and_video_messages = True
+    is_forum = True
+    active_usernames = ["These", "Are", "Usernames!"]
+    emoji_status_custom_emoji_id = "VeryUniqueCustomEmojiID"
 
     def test_slot_behaviour(self, chat, recwarn, mro_slots):
         for attr in chat.__slots__:
@@ -98,6 +106,12 @@ class TestChat:
             'location': self.location.to_dict(),
             'join_to_send_messages': self.join_to_send_messages,
             'join_by_request': self.join_by_request,
+            'has_restricted_voice_and_video_messages': (
+                self.has_restricted_voice_and_video_messages
+            ),
+            "is_forum": self.is_forum,
+            "active_usernames": self.active_usernames,
+            "emoji_status_custom_emoji_id": self.emoji_status_custom_emoji_id,
         }
         chat = Chat.de_json(json_dict, bot)
 
@@ -119,6 +133,13 @@ class TestChat:
         assert chat.location.address == self.location.address
         assert chat.join_to_send_messages == self.join_to_send_messages
         assert chat.join_by_request == self.join_by_request
+        assert (
+            chat.has_restricted_voice_and_video_messages
+            == self.has_restricted_voice_and_video_messages
+        )
+        assert chat.is_forum == self.is_forum
+        assert chat.active_usernames == self.active_usernames
+        assert chat.emoji_status_custom_emoji_id == self.emoji_status_custom_emoji_id
 
     def test_to_dict(self, chat):
         chat_dict = chat.to_dict()
@@ -139,6 +160,13 @@ class TestChat:
         assert chat_dict['location'] == chat.location.to_dict()
         assert chat_dict["join_to_send_messages"] == chat.join_to_send_messages
         assert chat_dict["join_by_request"] == chat.join_by_request
+        assert (
+            chat_dict["has_restricted_voice_and_video_messages"]
+            == chat.has_restricted_voice_and_video_messages
+        )
+        assert chat_dict["is_forum"] == chat.is_forum
+        assert chat_dict["active_usernames"] == chat.active_usernames
+        assert chat_dict["emoji_status_custom_emoji_id"] == chat.emoji_status_custom_emoji_id
 
     def test_link(self, chat):
         assert chat.link == f'https://t.me/{chat.username}'
@@ -782,6 +810,128 @@ class TestChat:
         monkeypatch.setattr(chat.bot, 'decline_chat_join_request', make_assertion)
         assert chat.decline_join_request(user_id=42)
 
+    def test_create_forum_topic(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == chat.id
+                and kwargs["name"] == "New Name"
+                and kwargs["icon_color"] == 0x6FB9F0
+                and kwargs["icon_custom_emoji_id"] == "12345"
+            )
+
+        assert check_shortcut_signature(
+            Chat.create_forum_topic, Bot.create_forum_topic, ["chat_id"], []
+        )
+        assert check_shortcut_call(
+            chat.create_forum_topic,
+            chat.bot,
+            "create_forum_topic",
+            shortcut_kwargs=["chat_id"],
+        )
+        assert check_defaults_handling(chat.create_forum_topic, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "create_forum_topic", make_assertion)
+        assert chat.create_forum_topic(
+            name="New Name", icon_color=0x6FB9F0, icon_custom_emoji_id="12345"
+        )
+
+    def test_edit_forum_topic(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == chat.id
+                and kwargs["message_thread_id"] == 42
+                and kwargs["name"] == "New Name"
+                and kwargs["icon_custom_emoji_id"] == "12345"
+            )
+
+        assert check_shortcut_signature(
+            Chat.edit_forum_topic, Bot.edit_forum_topic, ["chat_id"], []
+        )
+        assert check_shortcut_call(
+            chat.edit_forum_topic, chat.bot, "edit_forum_topic", shortcut_kwargs=["chat_id"]
+        )
+        assert check_defaults_handling(chat.edit_forum_topic, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "edit_forum_topic", make_assertion)
+        assert chat.edit_forum_topic(
+            message_thread_id=42, name="New Name", icon_custom_emoji_id="12345"
+        )
+
+    def test_close_forum_topic(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return kwargs["chat_id"] == chat.id and kwargs["message_thread_id"] == 42
+
+        assert check_shortcut_signature(
+            Chat.close_forum_topic, Bot.close_forum_topic, ["chat_id"], []
+        )
+        assert check_shortcut_call(
+            chat.close_forum_topic,
+            chat.bot,
+            "close_forum_topic",
+            shortcut_kwargs=["chat_id"],
+        )
+        assert check_defaults_handling(chat.close_forum_topic, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "close_forum_topic", make_assertion)
+        assert chat.close_forum_topic(message_thread_id=42)
+
+    def test_reopen_forum_topic(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return kwargs["chat_id"] == chat.id and kwargs["message_thread_id"] == 42
+
+        assert check_shortcut_signature(
+            Chat.reopen_forum_topic, Bot.reopen_forum_topic, ["chat_id"], []
+        )
+        assert check_shortcut_call(
+            chat.reopen_forum_topic,
+            chat.bot,
+            "reopen_forum_topic",
+            shortcut_kwargs=["chat_id"],
+        )
+        assert check_defaults_handling(chat.reopen_forum_topic, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "reopen_forum_topic", make_assertion)
+        assert chat.reopen_forum_topic(message_thread_id=42)
+
+    def test_delete_forum_topic(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return kwargs["chat_id"] == chat.id and kwargs["message_thread_id"] == 42
+
+        assert check_shortcut_signature(
+            Chat.delete_forum_topic, Bot.delete_forum_topic, ["chat_id"], []
+        )
+        assert check_shortcut_call(
+            chat.delete_forum_topic,
+            chat.bot,
+            "delete_forum_topic",
+            shortcut_kwargs=["chat_id"],
+        )
+        assert check_defaults_handling(chat.delete_forum_topic, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "delete_forum_topic", make_assertion)
+        assert chat.delete_forum_topic(message_thread_id=42)
+
+    def test_unpin_all_forum_topic_messages(self, monkeypatch, chat):
+        def make_assertion(*_, **kwargs):
+            return kwargs["chat_id"] == chat.id and kwargs["message_thread_id"] == 42
+
+        assert check_shortcut_signature(
+            Chat.unpin_all_forum_topic_messages,
+            Bot.unpin_all_forum_topic_messages,
+            ["chat_id"],
+            [],
+        )
+        assert check_shortcut_call(
+            chat.unpin_all_forum_topic_messages,
+            chat.bot,
+            "unpin_all_forum_topic_messages",
+            shortcut_kwargs=["chat_id"],
+        )
+        assert check_defaults_handling(chat.unpin_all_forum_topic_messages, chat.bot)
+
+        monkeypatch.setattr(chat.bot, "unpin_all_forum_topic_messages", make_assertion)
+        assert chat.unpin_all_forum_topic_messages(message_thread_id=42)
+
     def test_equality(self):
         a = Chat(self.id_, self.title, self.type_)
         b = Chat(self.id_, self.title, self.type_)
