@@ -34,6 +34,7 @@ def chat_admin_rights():
         can_edit_messages=True,
         can_manage_chat=True,
         can_manage_video_chats=True,
+        can_manage_topics=True,
         is_anonymous=True,
     )
 
@@ -57,6 +58,7 @@ class TestChatAdministratorRights:
             'can_edit_messages': True,
             'can_manage_chat': True,
             'can_manage_video_chats': True,
+            "can_manage_topics": True,
             'is_anonymous': True,
         }
         chat_administrator_rights_de = ChatAdministratorRights.de_json(json_dict, bot)
@@ -79,13 +81,14 @@ class TestChatAdministratorRights:
         assert admin_rights_dict['can_manage_chat'] == car.can_manage_chat
         assert admin_rights_dict['is_anonymous'] == car.is_anonymous
         assert admin_rights_dict['can_manage_video_chats'] == car.can_manage_video_chats
+        assert admin_rights_dict["can_manage_topics"] == car.can_manage_topics
 
     def test_equality(self):
-        a = ChatAdministratorRights(True, False, False, False, False, False, False, False)
-        b = ChatAdministratorRights(True, False, False, False, False, False, False, False)
-        c = ChatAdministratorRights(False, False, False, False, False, False, False, False)
-        d = ChatAdministratorRights(True, True, False, False, False, False, False, False)
-        e = ChatAdministratorRights(True, True, False, False, False, False, False, False)
+        a = ChatAdministratorRights(True, False, False, False, False, False, False, False, False)
+        b = ChatAdministratorRights(True, False, False, False, False, False, False, False, False)
+        c = ChatAdministratorRights(False, False, False, False, False, False, False, False, False)
+        d = ChatAdministratorRights(True, True, False, False, False, False, False, False, False)
+        e = ChatAdministratorRights(True, True, False, False, False, False, False, False, False)
 
         assert a == b
         assert hash(a) == hash(b)
@@ -101,7 +104,7 @@ class TestChatAdministratorRights:
         assert hash(d) == hash(e)
 
     def test_all_rights(self):
-        f = ChatAdministratorRights(True, True, True, True, True, True, True, True)
+        f = ChatAdministratorRights(True, True, True, True, True, True, True, True, True)
         t = ChatAdministratorRights.all_rights()
         # if the dirs are the same, the attributes will all be there
         assert dir(f) == dir(t)
@@ -116,7 +119,7 @@ class TestChatAdministratorRights:
         assert f != t
 
     def test_no_rights(self):
-        f = ChatAdministratorRights(False, False, False, False, False, False, False, False)
+        f = ChatAdministratorRights(False, False, False, False, False, False, False, False, False)
         t = ChatAdministratorRights.no_rights()
         # if the dirs are the same, the attributes will all be there
         assert dir(f) == dir(t)
