@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -46,6 +46,15 @@ class TestEncryptedPassportElement:
     reverse_side = PassportFile('file_id', 50, 0)
     selfie = PassportFile('file_id', 50, 0)
 
+    def test_slot_behaviour(self, encrypted_passport_element, recwarn, mro_slots):
+        inst = encrypted_passport_element
+        for attr in inst.__slots__:
+            assert getattr(inst, attr, 'err') != 'err', f"got extra slot '{attr}'"
+        assert not inst.__dict__, f"got missing slot(s): {inst.__dict__}"
+        assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
+        inst.custom, inst.phone_number = 'should give warning', self.phone_number
+        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
+
     def test_expected_values(self, encrypted_passport_element):
         assert encrypted_passport_element.type == self.type_
         assert encrypted_passport_element.data == self.data
