@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -57,6 +57,14 @@ class TestFile:
     file_size = 28232
     file_content = 'Saint-Saëns'.encode()  # Intentionally contains unicode chars.
 
+    def test_slot_behaviour(self, file, recwarn, mro_slots):
+        for attr in file.__slots__:
+            assert getattr(file, attr, 'err') != 'err', f"got extra slot '{attr}'"
+        assert not file.__dict__, f"got missing slot(s): {file.__dict__}"
+        assert len(mro_slots(file)) == len(set(mro_slots(file))), "duplicate slot"
+        file.custom, file.file_id = 'should give warning', self.file_id
+        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
+
     def test_de_json(self, bot):
         json_dict = {
             'file_id': self.file_id,
@@ -81,7 +89,6 @@ class TestFile:
         assert file_dict['file_size'] == file.file_size
 
     @flaky(3, 1)
-    @pytest.mark.timeout(10)
     def test_error_get_empty_file_id(self, bot):
         with pytest.raises(TelegramError):
             bot.get_file(file_id='')
