@@ -43,6 +43,9 @@ from .test_audio import audio, audio_file  # noqa: F401
 # noinspection PyUnresolvedReferences
 from .test_document import document, document_file  # noqa: F401
 
+# noinspection PyUnresolvedReferences
+from .test_forum import emoji_id, real_topic  # noqa: F401
+
 # noinspection PyUnresolvedReferences
 from .test_photo import _photo, photo_file, photo, thumb  # noqa: F401
 
@@ -458,6 +461,19 @@ class TestSendMediaGroup:
             mes.caption_entities == [MessageEntity(MessageEntity.BOLD, 0, 5)] for mes in messages
         )
 
+    def test_send_media_group_with_message_thread_id(
+        self, bot, real_topic, forum_group_id, media_group  # noqa: F811
+    ):
+        messages = bot.send_media_group(
+            forum_group_id,
+            media_group,
+            message_thread_id=real_topic.message_thread_id,
+        )
+        assert isinstance(messages, list)
+        assert len(messages) == 3
+        assert all(isinstance(mes, Message) for mes in messages)
+        assert all(i.message_thread_id == real_topic.message_thread_id for i in messages)
+
     @flaky(3, 1)
     def test_send_media_group_all_args(self, bot, chat_id, media_group):
         m1 = bot.send_message(chat_id, text="test")
