@@ -110,7 +110,7 @@ def message(bot):
             )
         },
         {'photo': [PhotoSize('photo_id', 'unique_id', 50, 50)], 'caption': 'photo_file'},
-        {'sticker': Sticker('sticker_id', 'unique_id', 50, 50, True, False)},
+        {'sticker': Sticker('sticker_id', 'unique_id', 50, 50, True, False, Sticker.REGULAR)},
         {'video': Video('video_id', 'unique_id', 12, 12, 12), 'caption': 'video_file'},
         {'voice': Voice('voice_id', 'unique_id', 5)},
         {'video_note': VideoNote('video_note_id', 'unique_id', 20, 12)},
@@ -196,6 +196,7 @@ def message(bot):
             )
         },
         {'web_app_data': WebAppData('some_data', 'some_button_text')},
+        {"message_thread_id": 123},
     ],
     ids=[
         'forwarded_user',
@@ -252,6 +253,7 @@ def message(bot):
         'is_automatic_forward',
         'has_protected_content',
         'web_app_data',
+        'message_thread_id',
     ],
 )
 def message_params(bot, request):
@@ -522,6 +524,36 @@ class TestMessage:
         )
         assert expected == message.text_markdown
 
+    @pytest.mark.parametrize(
+        "type_",
+        argvalues=[
+            "text_html",
+            "text_html_urled",
+            "text_markdown",
+            "text_markdown_urled",
+            "text_markdown_v2",
+            "text_markdown_v2_urled",
+        ],
+    )
+    def test_text_custom_emoji(self, type_):
+        text = "Look a custom emoji: 😎"
+        expected = "Look a custom emoji: 😎"
+        emoji_entity = MessageEntity(
+            type=MessageEntity.CUSTOM_EMOJI,
+            offset=21,
+            length=2,
+            custom_emoji_id="5472409228461217725",
+        )
+        message = Message(
+            1,
+            from_user=self.from_user,
+            date=self.date,
+            chat=self.chat,
+            text=text,
+            entities=[emoji_entity],
+        )
+        assert expected == message[type_]
+
     def test_caption_html_simple(self):
         test_html_string = (
             '<u>Test</u> for &lt;<b>bold</b>, <i>ita_lic</i>, '
@@ -631,6 +663,36 @@ class TestMessage:
         )
         assert expected == message.caption_markdown
 
+    @pytest.mark.parametrize(
+        "type_",
+        argvalues=[
+            "caption_html",
+            "caption_html_urled",
+            "caption_markdown",
+            "caption_markdown_urled",
+            "caption_markdown_v2",
+            "caption_markdown_v2_urled",
+        ],
+    )
+    def test_caption_custom_emoji(self, type_):
+        caption = "Look a custom emoji: 😎"
+        expected = "Look a custom emoji: 😎"
+        emoji_entity = MessageEntity(
+            type=MessageEntity.CUSTOM_EMOJI,
+            offset=21,
+            length=2,
+            custom_emoji_id="5472409228461217725",
+        )
+        message = Message(
+            1,
+            from_user=self.from_user,
+            date=self.date,
+            chat=self.chat,
+            caption=caption,
+            caption_entities=[emoji_entity],
+        )
+        assert expected == message[type_]
+
     def test_parse_entities_url_emoji(self):
         url = b'http://github.com/?unicode=\\u2713\\U0001f469'.decode('unicode-escape')
         text = 'some url'
@@ -1574,6 +1636,122 @@ class TestMessage:
         finally:
             message.bot.defaults = None
 
+    def test_edit_forum_topic(self, monkeypatch, message):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == message.chat_id
+                and kwargs["message_thread_id"] == message.message_thread_id
+                and kwargs["name"] == "New Name"
+                and kwargs["icon_custom_emoji_id"] == "12345"
+            )
+
+        assert check_shortcut_signature(
+            Message.edit_forum_topic, Bot.edit_forum_topic, ["chat_id", "message_thread_id"], []
+        )
+        assert check_shortcut_call(
+            message.edit_forum_topic,
+            message.bot,
+            "edit_forum_topic",
+            shortcut_kwargs=["chat_id", "message_thread_id"],
+        )
+        assert check_defaults_handling(message.edit_forum_topic, message.bot)
+
+        monkeypatch.setattr(message.bot, "edit_forum_topic", make_assertion)
+        assert message.edit_forum_topic(name="New Name", icon_custom_emoji_id="12345")
+
+    def test_close_forum_topic(self, monkeypatch, message):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == message.chat_id
+                and kwargs["message_thread_id"] == message.message_thread_id
+            )
+
+        assert check_shortcut_signature(
+            Message.close_forum_topic, Bot.close_forum_topic, ["chat_id", "message_thread_id"], []
+        )
+        assert check_shortcut_call(
+            message.close_forum_topic,
+            message.bot,
+            "close_forum_topic",
+            shortcut_kwargs=["chat_id", "message_thread_id"],
+        )
+        assert check_defaults_handling(message.close_forum_topic, message.bot)
+
+        monkeypatch.setattr(message.bot, "close_forum_topic", make_assertion)
+        assert message.close_forum_topic()
+
+    def test_reopen_forum_topic(self, monkeypatch, message):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == message.chat_id
+                and kwargs["message_thread_id"] == message.message_thread_id
+            )
+
+        assert check_shortcut_signature(
+            Message.reopen_forum_topic,
+            Bot.reopen_forum_topic,
+            ["chat_id", "message_thread_id"],
+            [],
+        )
+        assert check_shortcut_call(
+            message.reopen_forum_topic,
+            message.bot,
+            "reopen_forum_topic",
+            shortcut_kwargs=["chat_id", "message_thread_id"],
+        )
+        assert check_defaults_handling(message.reopen_forum_topic, message.bot)
+
+        monkeypatch.setattr(message.bot, "reopen_forum_topic", make_assertion)
+        assert message.reopen_forum_topic()
+
+    def test_delete_forum_topic(self, monkeypatch, message):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == message.chat_id
+                and kwargs["message_thread_id"] == message.message_thread_id
+            )
+
+        assert check_shortcut_signature(
+            Message.delete_forum_topic,
+            Bot.delete_forum_topic,
+            ["chat_id", "message_thread_id"],
+            [],
+        )
+        assert check_shortcut_call(
+            message.delete_forum_topic,
+            message.bot,
+            "delete_forum_topic",
+            shortcut_kwargs=["chat_id", "message_thread_id"],
+        )
+        assert check_defaults_handling(message.delete_forum_topic, message.bot)
+
+        monkeypatch.setattr(message.bot, "delete_forum_topic", make_assertion)
+        assert message.delete_forum_topic()
+
+    def test_unpin_all_forum_topic_messages(self, monkeypatch, message):
+        def make_assertion(*_, **kwargs):
+            return (
+                kwargs["chat_id"] == message.chat_id
+                and kwargs["message_thread_id"] == message.message_thread_id
+            )
+
+        assert check_shortcut_signature(
+            Message.unpin_all_forum_topic_messages,
+            Bot.unpin_all_forum_topic_messages,
+            ["chat_id", "message_thread_id"],
+            [],
+        )
+        assert check_shortcut_call(
+            message.unpin_all_forum_topic_messages,
+            message.bot,
+            "unpin_all_forum_topic_messages",
+            shortcut_kwargs=["chat_id", "message_thread_id"],
+        )
+        assert check_defaults_handling(message.unpin_all_forum_topic_messages, message.bot)
+
+        monkeypatch.setattr(message.bot, "unpin_all_forum_topic_messages", make_assertion)
+        assert message.unpin_all_forum_topic_messages()
+
     def test_equality(self):
         id_ = 1
         a = Message(
