@@ -102,6 +102,8 @@ def check_method(h4):
         ignored |= {'current_offset'}  # Added for ease of use
     elif name == 'promoteChatMember':
         ignored |= {'can_manage_voice_chats'}  # for backwards compatibility
+    elif name == 'createNewStickerSet':
+        ignored |= {'contains_masks'}  # for backwards compatibility
 
     assert (sig.parameters.keys() ^ checked) - ignored == set()
 
@@ -172,6 +174,7 @@ def check_object(h4):
             'is_anonymous',
             'is_member',
             'until_date',
+            'can_manage_topics',
         }
     if name == 'BotCommandScope':
         ignored |= {'type'}  # attributes common to all subclasses
@@ -195,7 +198,8 @@ def check_object(h4):
             'voice_chat_scheduled',
             'voice_chat_started',
         }
-
+    elif name == 'StickerSet':
+        ignored |= {'contains_masks'}  # for backwards compatibility
     assert (sig.parameters.keys() ^ checked) - ignored == set()
 
 
