@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-import pytest
 from flaky import flaky
 
 from telegram import ParseMode
@@ -30,8 +29,16 @@ class TestParseMode:
     )
     formatted_text_formatted = 'bold italic link name.'
 
+    def test_slot_behaviour(self, recwarn, mro_slots):
+        inst = ParseMode()
+        for attr in inst.__slots__:
+            assert getattr(inst, attr, 'err') != 'err', f"got extra slot '{attr}'"
+        assert not inst.__dict__, f"got missing slot(s): {inst.__dict__}"
+        assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
+        inst.custom = 'should give warning'
+        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
+
     @flaky(3, 1)
-    @pytest.mark.timeout(10)
     def test_send_message_with_parse_mode_markdown(self, bot, chat_id):
         message = bot.send_message(
             chat_id=chat_id, text=self.markdown_text, parse_mode=ParseMode.MARKDOWN
@@ -40,7 +47,6 @@ class TestParseMode:
         assert message.text == self.formatted_text_formatted
 
     @flaky(3, 1)
-    @pytest.mark.timeout(10)
     def test_send_message_with_parse_mode_html(self, bot, chat_id):
         message = bot.send_message(chat_id=chat_id, text=self.html_text, parse_mode=ParseMode.HTML)
 
