@@ -473,7 +473,15 @@ class TestPhoto:
         b = PhotoSize('', photo.file_unique_id, self.width, self.height)
         c = PhotoSize(photo.file_id, photo.file_unique_id, 0, 0)
         d = PhotoSize('', '', self.width, self.height)
-        e = Sticker(photo.file_id, photo.file_unique_id, self.width, self.height, False, False)
+        e = Sticker(
+            photo.file_id,
+            photo.file_unique_id,
+            self.width,
+            self.height,
+            False,
+            False,
+            Sticker.REGULAR,
+        )
 
         assert a == b
         assert hash(a) == hash(b)
