@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -15,7 +15,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 import pytest
 
 from datetime import datetime
@@ -34,6 +33,14 @@ class TestPollOption:
     text = "test option"
     voter_count = 3
 
+    def test_slot_behaviour(self, poll_option, mro_slots, recwarn):
+        for attr in poll_option.__slots__:
+            assert getattr(poll_option, attr, 'err') != 'err', f"got extra slot '{attr}'"
+        assert not poll_option.__dict__, f"got missing slot(s): {poll_option.__dict__}"
+        assert len(mro_slots(poll_option)) == len(set(mro_slots(poll_option))), "duplicate slot"
+        poll_option.custom, poll_option.text = 'should give warning', self.text
+        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
+
     def test_de_json(self):
         json_dict = {'text': self.text, 'voter_count': self.voter_count}
         poll_option = PollOption.de_json(json_dict, None)
