@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,13 +16,22 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 import pytest
 
 from telegram import TelegramError
 from telegram.utils.request import Request
 
 
+def test_slot_behaviour(recwarn, mro_slots):
+    inst = Request()
+    for attr in inst.__slots__:
+        assert getattr(inst, attr, 'err') != 'err', f"got extra slot '{attr}'"
+    assert not inst.__dict__, f"got missing slot(s): {inst.__dict__}"
+    assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
+    inst.custom, inst._connect_timeout = 'should give warning', 10
+    assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
+
+
 def test_replaced_unprintable_char():
     """
     Clients can send arbitrary bytes in callback data.
