@@ -83,6 +83,8 @@ class TestSticker:
     thumb_width = 319
     thumb_height = 320
     thumb_file_size = 21472
+    type = Sticker.REGULAR
+    custom_emoji_id = "ThisIsSuchACustomEmojiID"
 
     sticker_file_id = '5a3128a4d2a04750b5b58397f3b5e812'
     sticker_file_unique_id = 'adc3145fd2e84d95b64d68eaa22aa33e'
@@ -119,6 +121,7 @@ class TestSticker:
         assert sticker.thumb.width == self.thumb_width
         assert sticker.thumb.height == self.thumb_height
         assert sticker.thumb.file_size == self.thumb_file_size
+        assert sticker.type == self.type
         # we need to be a premium TG user to send a premium sticker, so the below is not tested
         # assert sticker.premium_animation == self.premium_animation
 
@@ -150,6 +153,7 @@ class TestSticker:
         assert message.sticker.thumb.height == sticker.thumb.height
         assert message.sticker.thumb.file_size == sticker.thumb.file_size
         assert message.has_protected_content
+        assert message.sticker.type == sticker.type
 
     @flaky(3, 1)
     def test_get_and_download(self, bot, sticker):
@@ -192,6 +196,7 @@ class TestSticker:
         assert message.sticker.is_animated == sticker.is_animated
         assert message.sticker.is_video == sticker.is_video
         assert message.sticker.file_size == sticker.file_size
+        assert message.sticker.type == sticker.type
 
         assert isinstance(message.sticker.thumb, PhotoSize)
         assert isinstance(message.sticker.thumb.file_id, str)
@@ -214,6 +219,8 @@ class TestSticker:
             'emoji': self.emoji,
             'file_size': self.file_size,
             'premium_animation': self.premium_animation.to_dict(),
+            'type': self.type,
+            'custom_emoji_id': self.custom_emoji_id,
         }
         json_sticker = Sticker.de_json(json_dict, bot)
 
@@ -227,6 +234,8 @@ class TestSticker:
         assert json_sticker.file_size == self.file_size
         assert json_sticker.thumb == sticker.thumb
         assert json_sticker.premium_animation == self.premium_animation
+        assert json_sticker.type == self.type
+        assert json_sticker.custom_emoji_id == self.custom_emoji_id
 
     def test_send_with_sticker(self, monkeypatch, bot, chat_id, sticker):
         def test(url, data, **kwargs):
@@ -297,6 +306,7 @@ class TestSticker:
         assert sticker_dict['is_video'] == sticker.is_video
         assert sticker_dict['file_size'] == sticker.file_size
         assert sticker_dict['thumb'] == sticker.thumb.to_dict()
+        assert sticker_dict["type"] == sticker.type
 
     @flaky(3, 1)
     def test_error_send_empty_file(self, bot, chat_id):
@@ -330,6 +340,16 @@ class TestSticker:
         }
         assert premium_sticker.premium_animation.to_dict() == premium_sticker_dict
 
+    @flaky(3, 1)
+    def test_custom_emoji(self, bot):
+        # testing custom emoji stickers is as much of an annoyance as the premium animation, see
+        # in test_premium_animation
+        custom_emoji_set = bot.get_sticker_set("PTBStaticEmojiTestPack")
+        # the first one to appear here is a sticker with unique file id of AQADjBsAAkKD0Uty
+        # this could change in the future ofc.
+        custom_emoji_sticker = custom_emoji_set.stickers[0]
+        assert custom_emoji_sticker.custom_emoji_id == "6046140249875156202"
+
     def test_equality(self, sticker):
         a = Sticker(
             sticker.file_id,
@@ -338,12 +358,35 @@ class TestSticker:
             self.height,
             self.is_animated,
             self.is_video,
+            self.type,
         )
         b = Sticker(
-            '', sticker.file_unique_id, self.width, self.height, self.is_animated, self.is_video
+            "",
+            sticker.file_unique_id,
+            self.width,
+            self.height,
+            self.is_animated,
+            self.is_video,
+            self.type,
+        )
+        c = Sticker(
+            sticker.file_id,
+            sticker.file_unique_id,
+            0,
+            0,
+            False,
+            True,
+            self.type,
+        )
+        d = Sticker(
+            "",
+            "",
+            self.width,
+            self.height,
+            self.is_animated,
+            self.is_video,
+            self.type,
         )
-        c = Sticker(sticker.file_id, sticker.file_unique_id, 0, 0, False, True)
-        d = Sticker('', '', self.width, self.height, self.is_animated, self.is_video)
         e = PhotoSize(
             sticker.file_id, sticker.file_unique_id, self.width, self.height, self.is_animated
         )
@@ -416,8 +459,9 @@ class TestStickerSet:
     is_animated = True
     is_video = True
     contains_masks = False
-    stickers = [Sticker('file_id', 'file_un_id', 512, 512, True, True)]
+    stickers = [Sticker('file_id', 'file_un_id', 512, 512, True, True, Sticker.REGULAR)]
     name = 'NOTAREALNAME'
+    sticker_type = Sticker.REGULAR
 
     def test_de_json(self, bot, sticker):
         name = f'test_by_{bot.username}'
@@ -429,6 +473,7 @@ class TestStickerSet:
             'contains_masks': self.contains_masks,
             'stickers': [x.to_dict() for x in self.stickers],
             'thumb': sticker.thumb.to_dict(),
+            'sticker_type': self.sticker_type,
         }
         sticker_set = StickerSet.de_json(json_dict, bot)
 
@@ -439,6 +484,7 @@ class TestStickerSet:
         assert sticker_set.contains_masks == self.contains_masks
         assert sticker_set.stickers == self.stickers
         assert sticker_set.thumb == sticker.thumb
+        assert sticker_set.sticker_type == self.sticker_type
 
     def test_create_sticker_set(
         self, bot, chat_id, sticker_file, animated_sticker_file, video_sticker_file
@@ -526,6 +572,8 @@ class TestStickerSet:
         assert sticker_set_dict['is_video'] == sticker_set.is_video
         assert sticker_set_dict['contains_masks'] == sticker_set.contains_masks
         assert sticker_set_dict['stickers'][0] == sticker_set.stickers[0].to_dict()
+        assert sticker_set_dict["thumb"] == sticker_set.thumb.to_dict()
+        assert sticker_set_dict["sticker_type"] == sticker_set.sticker_type
 
     @flaky(3, 1)
     def test_bot_methods_2_png(self, bot, sticker_set):
@@ -626,6 +674,32 @@ class TestStickerSet:
         assert test_flag
         monkeypatch.delattr(bot, '_post')
 
+    def test_create_new_sticker_all_params(self, monkeypatch, bot, chat_id, mask_position):
+        def make_assertion(_, data, *args, **kwargs):
+            assert data["user_id"] == chat_id
+            assert data["name"] == "name"
+            assert data["title"] == "title"
+            assert data["emojis"] == "emoji"
+            assert data["mask_position"] == mask_position.to_json()
+            assert data["png_sticker"] == "wow.png"
+            assert data["tgs_sticker"] == "wow.tgs"
+            assert data["webm_sticker"] == "wow.webm"
+            assert data["sticker_type"] == Sticker.MASK
+
+        monkeypatch.setattr(bot, "_post", make_assertion)
+        bot.create_new_sticker_set(
+            chat_id,
+            "name",
+            "title",
+            "emoji",
+            mask_position=mask_position,
+            png_sticker="wow.png",
+            tgs_sticker="wow.tgs",
+            webm_sticker="wow.webm",
+            sticker_type=Sticker.MASK,
+        )
+        monkeypatch.delattr(bot, "_post")
+
     def test_add_sticker_to_set_local_files(self, monkeypatch, bot, chat_id):
         # For just test that the correct paths are passed as we have no local bot API set up
         test_flag = False
@@ -675,6 +749,8 @@ class TestStickerSet:
             self.contains_masks,
             self.stickers,
             self.is_video,
+            None,
+            self.sticker_type,
         )
         b = StickerSet(
             self.name,
@@ -684,9 +760,16 @@ class TestStickerSet:
             self.stickers,
             self.is_video,
         )
-        c = StickerSet(self.name, None, None, None, None, None)
+        c = StickerSet(self.name, None, None, None, None, None, None, Sticker.CUSTOM_EMOJI)
         d = StickerSet(
-            'blah', self.title, self.is_animated, self.contains_masks, self.stickers, self.is_video
+            'blah',
+            self.title,
+            self.is_animated,
+            self.contains_masks,
+            self.stickers,
+            self.is_video,
+            None,
+            self.sticker_type,
         )
         e = Audio(self.name, '', 0, None, None)
 
@@ -762,3 +845,23 @@ class TestMaskPosition:
 
         assert a != e
         assert hash(a) != hash(e)
+
+
+class TestGetCustomEmojiSticker:
+    def test_custom_emoji_sticker(self, bot):
+        # we use the same ID as in test_custom_emoji
+        emoji_sticker_list = bot.get_custom_emoji_stickers(["6046140249875156202"])
+        assert emoji_sticker_list[0].emoji == "😎"
+        assert emoji_sticker_list[0].height == 100
+        assert emoji_sticker_list[0].width == 100
+        assert not emoji_sticker_list[0].is_animated
+        assert not emoji_sticker_list[0].is_video
+        assert emoji_sticker_list[0].set_name == "PTBStaticEmojiTestPack"
+        assert emoji_sticker_list[0].type == Sticker.CUSTOM_EMOJI
+        assert emoji_sticker_list[0].custom_emoji_id == "6046140249875156202"
+        assert emoji_sticker_list[0].thumb.width == 100
+        assert emoji_sticker_list[0].thumb.height == 100
+        assert emoji_sticker_list[0].thumb.file_size == 3614
+        assert emoji_sticker_list[0].thumb.file_unique_id == "AQAD6gwAAoY06FNy"
+        assert emoji_sticker_list[0].file_size == 3678
+        assert emoji_sticker_list[0].file_unique_id == "AgAD6gwAAoY06FM"
