@@ -35,6 +35,8 @@ def json_dict():
         'can_join_groups': TestUser.can_join_groups,
         'can_read_all_group_messages': TestUser.can_read_all_group_messages,
         'supports_inline_queries': TestUser.supports_inline_queries,
+        'is_premium': TestUser.is_premium,
+        'added_to_attachment_menu': TestUser.added_to_attachment_menu,
     }
 
 
@@ -51,6 +53,8 @@ def user(bot):
         can_read_all_group_messages=TestUser.can_read_all_group_messages,
         supports_inline_queries=TestUser.supports_inline_queries,
         bot=bot,
+        is_premium=TestUser.is_premium,
+        added_to_attachment_menu=TestUser.added_to_attachment_menu,
     )
 
 
@@ -64,6 +68,8 @@ class TestUser:
     can_join_groups = True
     can_read_all_group_messages = True
     supports_inline_queries = False
+    is_premium = True
+    added_to_attachment_menu = False
 
     def test_slot_behaviour(self, user, mro_slots, recwarn):
         for attr in user.__slots__:
@@ -85,6 +91,8 @@ class TestUser:
         assert user.can_join_groups == self.can_join_groups
         assert user.can_read_all_group_messages == self.can_read_all_group_messages
         assert user.supports_inline_queries == self.supports_inline_queries
+        assert user.is_premium == self.is_premium
+        assert user.added_to_attachment_menu == self.added_to_attachment_menu
 
     def test_de_json_without_username(self, json_dict, bot):
         del json_dict['username']
@@ -100,6 +108,8 @@ class TestUser:
         assert user.can_join_groups == self.can_join_groups
         assert user.can_read_all_group_messages == self.can_read_all_group_messages
         assert user.supports_inline_queries == self.supports_inline_queries
+        assert user.is_premium == self.is_premium
+        assert user.added_to_attachment_menu == self.added_to_attachment_menu
 
     def test_de_json_without_username_and_last_name(self, json_dict, bot):
         del json_dict['username']
@@ -116,6 +126,8 @@ class TestUser:
         assert user.can_join_groups == self.can_join_groups
         assert user.can_read_all_group_messages == self.can_read_all_group_messages
         assert user.supports_inline_queries == self.supports_inline_queries
+        assert user.is_premium == self.is_premium
+        assert user.added_to_attachment_menu == self.added_to_attachment_menu
 
     def test_name(self, user):
         assert user.name == '@username'
@@ -430,6 +442,42 @@ class TestUser:
         monkeypatch.setattr(user.bot, 'copy_message', make_assertion)
         assert user.copy_message(chat_id='chat_id', message_id='message_id')
 
+    def test_instance_method_get_menu_button(self, monkeypatch, user):
+        def make_assertion(*_, **kwargs):
+            return kwargs['chat_id'] == user.id
+
+        assert check_shortcut_signature(
+            User.get_menu_button, Bot.get_chat_menu_button, ['chat_id'], []
+        )
+        assert check_shortcut_call(
+            user.get_menu_button,
+            user.bot,
+            'get_chat_menu_button',
+            shortcut_kwargs=['chat_id'],
+        )
+        assert check_defaults_handling(user.get_menu_button, user.bot)
+
+        monkeypatch.setattr(user.bot, 'get_chat_menu_button', make_assertion)
+        assert user.get_menu_button()
+
+    def test_instance_method_set_menu_button(self, monkeypatch, user):
+        def make_assertion(*_, **kwargs):
+            return kwargs['chat_id'] == user.id and kwargs['menu_button'] == 'menu_button'
+
+        assert check_shortcut_signature(
+            User.set_menu_button, Bot.set_chat_menu_button, ['chat_id'], []
+        )
+        assert check_shortcut_call(
+            user.set_menu_button,
+            user.bot,
+            'set_chat_menu_button',
+            shortcut_kwargs=['chat_id'],
+        )
+        assert check_defaults_handling(user.set_menu_button, user.bot)
+
+        monkeypatch.setattr(user.bot, 'set_chat_menu_button', make_assertion)
+        assert user.set_menu_button(menu_button='menu_button')
+
     def test_instance_method_approve_join_request(self, monkeypatch, user):
         def make_assertion(*_, **kwargs):
             chat_id = kwargs['chat_id'] == 'chat_id'
